@@ -60,16 +60,19 @@
   :prefix "riece-"
   :group 'riece)
 
-(defcustom riece-truncate-partial-width-windows nil
-  "If non-nil, truncate lines in splitting windows such as others buffer."
-  :type 'boolean
-  :group 'riece-looks)
-
 (defcustom riece-use-full-window t
   "If non-nil, whole Emacs window is used to display dialogue."
   :type 'boolean
   :group 'riece-looks)
 
+(defcustom riece-window-center-line -2
+  "Line number of center point in window when scrolling.
+If nil, erases the entire frame and then redraws with point in the
+center of the window.  Negative means relative to bottom of window.
+See the document of the function `recenter'."
+  :type 'integer
+  :group 'riece-looks)
+
 (defcustom riece-directory (expand-file-name "~/.riece")
   "Where to look for data files."
   :type 'directory
